==> SPIRV-LLVM-Translator-21.1.2.tar.lz: SPIRV-LLVM-Translator-21.1.2/lib/SPIRV/libSPIRV/SPIRVOpCodeEnumInternal.h <==
#include "spirv_internal.hpp"

_SPIRV_OP_INTERNAL(Forward, internal::OpForward)
_SPIRV_OP_INTERNAL(TypeTokenINTEL, internal::OpTypeTokenINTEL)
_SPIRV_OP_INTERNAL(TypeJointMatrixINTEL, internal::OpTypeJointMatrixINTEL)
_SPIRV_OP_INTERNAL(JointMatrixLoadINTEL, internal::OpJointMatrixLoadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixStoreINTEL, internal::OpJointMatrixStoreINTEL)
_SPIRV_OP_INTERNAL(JointMatrixMadINTEL, internal::OpJointMatrixMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixSUMadINTEL, internal::OpJointMatrixSUMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixUSMadINTEL, internal::OpJointMatrixUSMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixUUMadINTEL, internal::OpJointMatrixUUMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixWorkItemLengthINTEL,
                   internal::OpJointMatrixWorkItemLengthINTEL)
_SPIRV_OP_INTERNAL(JointMatrixGetElementCoordINTEL,
                   internal::OpJointMatrixGetElementCoordINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixPrefetchINTEL,
                   internal::OpCooperativeMatrixPrefetchINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixLoadCheckedINTEL,
                   internal::OpCooperativeMatrixLoadCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixStoreCheckedINTEL,
                   internal::OpCooperativeMatrixStoreCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixConstructCheckedINTEL,
                   internal::OpCooperativeMatrixConstructCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixLoadOffsetINTEL,
                   internal::OpCooperativeMatrixLoadOffsetINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixStoreOffsetINTEL,
                   internal::OpCooperativeMatrixStoreOffsetINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixApplyFunctionINTEL,
                   internal::OpCooperativeMatrixApplyFunctionINTEL)
_SPIRV_OP_INTERNAL(MaskedGatherINTEL, internal::OpMaskedGatherINTEL)
_SPIRV_OP_INTERNAL(MaskedScatterINTEL, internal::OpMaskedScatterINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceAsyncINTEL, internal::OpTaskSequenceAsyncINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceCreateINTEL, internal::OpTaskSequenceCreateINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceGetINTEL, internal::OpTaskSequenceGetINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceReleaseINTEL,
                   internal::OpTaskSequenceReleaseINTEL)
_SPIRV_OP_INTERNAL(TypeTaskSequenceINTEL, internal::OpTypeTaskSequenceINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToImageINTEL,
                   internal::ConvertHandleToImageINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
                   internal::ConvertHandleToSamplerINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
                   internal::ConvertHandleToSampledImageINTEL)
_SPIRV_OP_INTERNAL(PredicatedLoadINTEL,
                   internal::OpPredicatedLoadINTEL)
_SPIRV_OP_INTERNAL(PredicatedStoreINTEL,
                   internal::OpPredicatedStoreINTEL)

==> SPIRV-LLVM-Translator-21.1.3.tar.lz: SPIRV-LLVM-Translator-21.1.3/lib/SPIRV/libSPIRV/SPIRVOpCodeEnumInternal.h <==
#include "spirv_internal.hpp"

_SPIRV_OP_INTERNAL(Forward, internal::OpForward)
_SPIRV_OP_INTERNAL(TypeTokenINTEL, internal::OpTypeTokenINTEL)
_SPIRV_OP_INTERNAL(TypeJointMatrixINTEL, internal::OpTypeJointMatrixINTEL)
_SPIRV_OP_INTERNAL(JointMatrixLoadINTEL, internal::OpJointMatrixLoadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixStoreINTEL, internal::OpJointMatrixStoreINTEL)
_SPIRV_OP_INTERNAL(JointMatrixMadINTEL, internal::OpJointMatrixMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixSUMadINTEL, internal::OpJointMatrixSUMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixUSMadINTEL, internal::OpJointMatrixUSMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixUUMadINTEL, internal::OpJointMatrixUUMadINTEL)
_SPIRV_OP_INTERNAL(JointMatrixWorkItemLengthINTEL,
                   internal::OpJointMatrixWorkItemLengthINTEL)
_SPIRV_OP_INTERNAL(JointMatrixGetElementCoordINTEL,
                   internal::OpJointMatrixGetElementCoordINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixPrefetchINTEL,
                   internal::OpCooperativeMatrixPrefetchINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixLoadCheckedINTEL,
                   internal::OpCooperativeMatrixLoadCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixStoreCheckedINTEL,
                   internal::OpCooperativeMatrixStoreCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixConstructCheckedINTEL,
                   internal::OpCooperativeMatrixConstructCheckedINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixLoadOffsetINTEL,
                   internal::OpCooperativeMatrixLoadOffsetINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixStoreOffsetINTEL,
                   internal::OpCooperativeMatrixStoreOffsetINTEL)
_SPIRV_OP_INTERNAL(CooperativeMatrixApplyFunctionINTEL,
                   internal::OpCooperativeMatrixApplyFunctionINTEL)
_SPIRV_OP_INTERNAL(MaskedGatherINTEL, internal::OpMaskedGatherINTEL)
_SPIRV_OP_INTERNAL(MaskedScatterINTEL, internal::OpMaskedScatterINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceAsyncINTEL, internal::OpTaskSequenceAsyncINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceCreateINTEL, internal::OpTaskSequenceCreateINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceGetINTEL, internal::OpTaskSequenceGetINTEL)
_SPIRV_OP_INTERNAL(TaskSequenceReleaseINTEL,
                   internal::OpTaskSequenceReleaseINTEL)
_SPIRV_OP_INTERNAL(TypeTaskSequenceINTEL, internal::OpTypeTaskSequenceINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToImageINTEL,
                   internal::ConvertHandleToImageINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
                   internal::ConvertHandleToSamplerINTEL)
_SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
                   internal::ConvertHandleToSampledImageINTEL)
_SPIRV_OP_INTERNAL(PredicatedLoadINTEL,
                   internal::OpPredicatedLoadINTEL)
_SPIRV_OP_INTERNAL(PredicatedStoreINTEL,
                   internal::OpPredicatedStoreINTEL)
_SPIRV_OP_INTERNAL(FSigmoidINTEL, internal::FSigmoidINTEL)
_SPIRV_OP_INTERNAL(ClampConvertFToFINTEL,
                   internal::OpClampConvertFToFINTEL)
_SPIRV_OP_INTERNAL(StochasticRoundFToFINTEL,
                   internal::OpStochasticRoundFToFINTEL)
_SPIRV_OP_INTERNAL(ClampStochasticRoundFToFINTEL,
                   internal::OpClampStochasticRoundFToFINTEL)
_SPIRV_OP_INTERNAL(ClampConvertFToSINTEL,
                   internal::OpClampConvertFToSINTEL)
_SPIRV_OP_INTERNAL(ClampStochasticRoundFToSINTEL,
                   internal::OpClampStochasticRoundFToSINTEL)
